# Welcome to rpkimancer's documentation

:::{toctree}
:maxdepth: 2

API Reference <generated/modules>
oids
:::

:::{include} ../README.md
:relative-docs: docs/
:relative-images:
:::

## Indices and tables

* {ref}`genindex`
* {ref}`modindex`
* {ref}`search`
